# Runs

Types:

```python
from vern.types import RunCreateResponse, RunRetrieveResponse
```

Methods:

- <code title="post /runs">client.runs.<a href="./src/vern/resources/runs.py">create</a>(\*\*<a href="src/vern/types/run_create_params.py">params</a>) -> <a href="./src/vern/types/run_create_response.py">RunCreateResponse</a></code>
- <code title="get /runs/{id}">client.runs.<a href="./src/vern/resources/runs.py">retrieve</a>(id) -> <a href="./src/vern/types/run_retrieve_response.py">RunRetrieveResponse</a></code>
